@@ -156,6 +156,26 @@ func TestDiffWithCompareToFormatJSON(t *testing.T) {
 	)
 }
 
+func TestDiffWithCompareToNoMetadataFormatJSON(t *testing.T) {
+	dir := path.Join("./testdata", testutil.CalcGoldenFileTestdataDirName())
+	GoldenFileCommandTest(
+		t,
+		testutil.CalcGoldenFileTestdataDirName(),
+		[]string{
+			"diff",
+			"--path",
+			dir,
+			"--compare-to",
+			path.Join(dir, "prior.json"),
+			"--format",
+			"json",
+		}, &GoldenFileOptions{
+			RunTerraformCLI: true,
+			IsJSON:          true,
+		},
+	)
+}
+
 func TestDiffWithCompareToPreserveSummary(t *testing.T) {
 	dir := path.Join("./testdata", testutil.CalcGoldenFileTestdataDirName())
 	GoldenFileCommandTest(
@@ -213,9 +233,7 @@ projects:
 			configFilePath,
 			"--compare-to",
 			path.Join(dir, "prior.json"),
-		}, &GoldenFileOptions{
-			RunTerraformCLI: true,
-		})
+		}, nil)
 }
 
 func TestDiffWithConfigFileCompareToDeletedProject(t *testing.T) {
@@ -240,9 +258,7 @@ projects:
 			configFilePath,
 			"--compare-to",
 			path.Join(dir, "prior.json"),
-		}, &GoldenFileOptions{
-			RunTerraformCLI: true,
-		})
+		}, nil)
 }
 
 func TestDiffCompareToError(t *testing.T) {
@@ -265,6 +281,21 @@ func TestDiffTerragruntNested(t *testing.T) {
 	GoldenFileCommandTest(t, testutil.CalcGoldenFileTestdataDirName(), []string{"diff", "--path", "../../examples", "--terraform-force-cli"}, nil)
 }
 
+func TestDiffTerragruntSyntaxError(t *testing.T) {
+	testName := testutil.CalcGoldenFileTestdataDirName()
+	dir := path.Join("./testdata", testName)
+	GoldenFileCommandTest(
+		t,
+		testutil.CalcGoldenFileTestdataDirName(),
+		[]string{
+			"diff",
+			"--compare-to", filepath.Join(dir, "baseline.withouterror.json"),
+			"--config-file", filepath.Join(dir, "infracost.config.yml"),
+		},
+		&GoldenFileOptions{},
+	)
+}
+
 func TestDiffWithTarget(t *testing.T) {
 	GoldenFileCommandTest(t, testutil.CalcGoldenFileTestdataDirName(), []string{"diff", "--path", "./testdata/plan_with_target.json"}, nil)
 }
