@@ -39,7 +39,7 @@ See https://infracost.io/docs/features/cli_commands/#upload-runs`,
 
       infracost upload --path infracost.json`,
 		ValidArgs: []string{"--", "-"},
-		RunE: func(cmd *cobra.Command, args []string) error {
+		RunE: checkAPIKeyIsValid(ctx, func(cmd *cobra.Command, args []string) error {
 			var err error
 
 			format, _ := cmd.Flags().GetString("format")
@@ -82,12 +82,8 @@ See https://infracost.io/docs/features/cli_commands/#upload-runs`,
 				logging.Logger.Warn().Err(err).Msg("could not report `infracost-upload` event")
 			}
 
-			if len(result.GovernanceFailures) > 0 {
-				return result.GovernanceFailures
-			}
-
 			return nil
-		},
+		}),
 	}
 
 	cmd.Flags().String("path", "p", "Path to Infracost JSON file.")
