@@ -1,24 +1,26 @@
 package funcs
 
 import (
+	"bytes"
 	"encoding/base64"
 	"fmt"
 	"io"
 	"os"
 	"path/filepath"
+	"strings"
 	"unicode/utf8"
 
 	"github.com/bmatcuk/doublestar"
+	"github.com/hashicorp/go-cty-funcs/filesystem"
 	"github.com/hashicorp/hcl/v2"
 	"github.com/hashicorp/hcl/v2/hclsyntax"
 	homedir "github.com/mitchellh/go-homedir"
 	"github.com/zclconf/go-cty/cty"
 	"github.com/zclconf/go-cty/cty/function"
+
+	"github.com/infracost/infracost/internal/logging"
 )
 
-// MakeFileFunc constructs a function that takes a file path and returns the
-// contents of that file, either directly as a string (where valid UTF-8 is
-// required) or as a string containing base64 bytes.
 func MakeFileFunc(baseDir string, encBase64 bool) function.Function {
 	return function.New(&function.Spec{
 		Params: []function.Parameter{
@@ -204,6 +206,11 @@ func MakeFileExistsFunc(baseDir string) function.Function {
 
 			// Ensure that the path is canonical for the host OS
 			path = filepath.Clean(path)
+			if err := isPathInRepo(path); err != nil {
+				logging.Logger.Debug().Msgf("isPathInRepo error: %s returning false for filesytem func", err)
+
+				return cty.False, nil
+			}
 
 			fi, err := os.Stat(path)
 			if err != nil {
@@ -258,6 +265,11 @@ func MakeFileSetFunc(baseDir string) function.Function {
 
 			var matchVals []cty.Value
 			for _, match := range matches {
+				if err := isPathInRepo(match); err != nil {
+					logging.Logger.Debug().Msgf("isPathInRepo error: %s skipping match for filesytem func", err)
+					continue
+				}
+
 				fi, err := os.Stat(match)
 
 				if err != nil {
@@ -291,68 +303,7 @@ func MakeFileSetFunc(baseDir string) function.Function {
 	})
 }
 
-// BasenameFunc constructs a function that takes a string containing a filesystem path
-// and removes all except the last portion from it.
-var BasenameFunc = function.New(&function.Spec{
-	Params: []function.Parameter{
-		{
-			Name: "path",
-			Type: cty.String,
-		},
-	},
-	Type: function.StaticReturnType(cty.String),
-	Impl: func(args []cty.Value, retType cty.Type) (cty.Value, error) {
-		return cty.StringVal(filepath.Base(args[0].AsString())), nil
-	},
-})
-
-// DirnameFunc constructs a function that takes a string containing a filesystem path
-// and removes the last portion from it.
-var DirnameFunc = function.New(&function.Spec{
-	Params: []function.Parameter{
-		{
-			Name: "path",
-			Type: cty.String,
-		},
-	},
-	Type: function.StaticReturnType(cty.String),
-	Impl: func(args []cty.Value, retType cty.Type) (cty.Value, error) {
-		return cty.StringVal(filepath.Dir(args[0].AsString())), nil
-	},
-})
-
-// AbsPathFunc constructs a function that converts a filesystem path to an absolute path
-var AbsPathFunc = function.New(&function.Spec{
-	Params: []function.Parameter{
-		{
-			Name: "path",
-			Type: cty.String,
-		},
-	},
-	Type: function.StaticReturnType(cty.String),
-	Impl: func(args []cty.Value, retType cty.Type) (cty.Value, error) {
-		absPath, err := filepath.Abs(args[0].AsString())
-		return cty.StringVal(filepath.ToSlash(absPath)), err
-	},
-})
-
-// PathExpandFunc constructs a function that expands a leading ~ character to the current user's home directory.
-var PathExpandFunc = function.New(&function.Spec{
-	Params: []function.Parameter{
-		{
-			Name: "path",
-			Type: cty.String,
-		},
-	},
-	Type: function.StaticReturnType(cty.String),
-	Impl: func(args []cty.Value, retType cty.Type) (cty.Value, error) {
-
-		homePath, err := homedir.Expand(args[0].AsString())
-		return cty.StringVal(homePath), err
-	},
-})
-
-func openFile(baseDir, path string) (*os.File, error) {
+func openFile(baseDir, path string) (io.Reader, error) {
 	path, err := homedir.Expand(path)
 	if err != nil {
 		return nil, fmt.Errorf("failed to expand ~: %s", err)
@@ -365,6 +316,12 @@ func openFile(baseDir, path string) (*os.File, error) {
 	// Ensure that the path is canonical for the host OS
 	path = filepath.Clean(path)
 
+	if err := isPathInRepo(path); err != nil {
+		logging.Logger.Debug().Msgf("isPathInRepo error: %s returning a blank buffer for filesytem func", err)
+
+		return bytes.NewBuffer([]byte{}), nil
+	}
+
 	return os.Open(path)
 }
 
@@ -437,7 +394,7 @@ func FileBase64(baseDir string, path cty.Value) (cty.Value, error) {
 //
 // If the path is empty then the result is ".", representing the current working directory.
 func Basename(path cty.Value) (cty.Value, error) {
-	return BasenameFunc.Call([]cty.Value{path})
+	return filesystem.BasenameFunc.Call([]cty.Value{path})
 }
 
 // Dirname takes a string containing a filesystem path and removes the last portion from it.
@@ -447,7 +404,7 @@ func Basename(path cty.Value) (cty.Value, error) {
 //
 // If the path is empty then the result is ".", representing the current working directory.
 func Dirname(path cty.Value) (cty.Value, error) {
-	return DirnameFunc.Call([]cty.Value{path})
+	return filesystem.DirnameFunc.Call([]cty.Value{path})
 }
 
 // Pathexpand takes a string that might begin with a `~` segment, and if so it replaces that segment with
@@ -458,5 +415,52 @@ func Dirname(path cty.Value) (cty.Value, error) {
 //
 // If the leading segment in the path is not `~` then the given path is returned unmodified.
 func Pathexpand(path cty.Value) (cty.Value, error) {
-	return PathExpandFunc.Call([]cty.Value{path})
+	return filesystem.PathExpandFunc.Call([]cty.Value{path})
+}
+
+func isPathInRepo(path string) error {
+	// isPathInRepo is a no-op when not running in github/gitlab app env.
+	ciPlatform := os.Getenv("INFRACOST_CI_PLATFORM")
+	if ciPlatform != "github_app" && ciPlatform != "gitlab_app" {
+		return nil
+	}
+
+	wd, err := os.Getwd()
+	if err != nil {
+		return err
+	}
+
+	if !filepath.IsAbs(path) {
+		path = filepath.Join(wd, path)
+	}
+
+	// ensure the path resolves to the real symlink path
+	path = symlinkPath(path)
+
+	clean := filepath.Clean(wd)
+	if wd != "" && !strings.HasPrefix(path, clean) {
+		return fmt.Errorf("file %s is not within the repository directory %s", path, wd)
+	}
+
+	return nil
+}
+
+// symlinkPath checks the given file path and returns the real path if it is a
+// symlink.
+func symlinkPath(filepathStr string) string {
+	fileInfo, err := os.Lstat(filepathStr)
+	if err != nil {
+		return filepathStr
+	}
+
+	if fileInfo.Mode()&os.ModeSymlink != 0 {
+		realPath, err := filepath.EvalSymlinks(filepathStr)
+		if err != nil {
+			return filepathStr
+		}
+
+		return realPath
+	}
+
+	return filepathStr
 }
