@@ -22,7 +22,6 @@ import (
 	"github.com/infracost/infracost/internal/config"
 	"github.com/infracost/infracost/internal/schema"
 	intSync "github.com/infracost/infracost/internal/sync"
-	"github.com/infracost/infracost/internal/ui"
 )
 
 var (
@@ -43,8 +42,6 @@ var (
 // .infracost/terraform_modules directory. We could implement a global cache in the future, but for now have decided
 // to go with the same approach as Terraform.
 type ModuleLoader struct {
-	NewSpinner ui.SpinnerFunc
-
 	// cachePath is the path to the directory that Infracost will download modules to.
 	// This is normally the top level directory of a multi-project environment, where the
 	// Infracost config file resides or project auto-detection starts from.
@@ -117,11 +114,6 @@ func (m *ModuleLoader) Load(path string) (man *Manifest, err error) {
 		}
 	}()
 
-	if m.NewSpinner != nil {
-		spin := m.NewSpinner("Downloading Terraform modules")
-		defer spin.Success()
-	}
-
 	manifest := &Manifest{}
 	manifestFilePath := m.manifestFilePath(path)
 	_, err = os.Stat(manifestFilePath)
@@ -467,22 +459,22 @@ func (m *ModuleLoader) cachePathRel(targetPath string) (string, error) {
 	if relerr == nil {
 		return rel, nil
 	}
-	m.logger.Info().Msgf("Failed to filepath.Rel cache=%s target=%s: %v", m.cachePath, targetPath, relerr)
+	m.logger.Debug().Msgf("Failed to filepath.Rel cache=%s target=%s: %v", m.cachePath, targetPath, relerr)
 
 	// try converting to absolute paths
 	absCachePath, abserr := filepath.Abs(m.cachePath)
 	if abserr != nil {
-		m.logger.Info().Msgf("Failed to filepath.Abs cachePath: %v", abserr)
+		m.logger.Debug().Msgf("Failed to filepath.Abs cachePath: %v", abserr)
 		return "", relerr
 	}
 
 	absTargetPath, abserr := filepath.Abs(targetPath)
 	if abserr != nil {
-		m.logger.Info().Msgf("Failed to filepath.Abs target: %v", abserr)
+		m.logger.Debug().Msgf("Failed to filepath.Abs target: %v", abserr)
 		return "", relerr
 	}
 
-	m.logger.Info().Msgf("Attempting filepath.Rel on abs paths cache=%s, target=%s", absCachePath, absTargetPath)
+	m.logger.Debug().Msgf("Attempting filepath.Rel on abs paths cache=%s, target=%s", absCachePath, absTargetPath)
 	return filepath.Rel(absCachePath, absTargetPath)
 }
 
