@@ -83,14 +83,14 @@ func TestNestedModules(t *testing.T) {
 			Source:      "registry.terraform.io/terraform-aws-modules/ec2-instance/aws",
 			Version:     "3.4.0",
 			Dir:         ".infracost/terraform_modules/f8b5f5ddb85ee755b31c8b76d2801f5b",
-			DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-ec2-instance?ref=v3.4.0",
+			DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-ec2-instance?ref=ab731d112e37971368066b5dbecf35b075a853aa",
 		},
 		{
 			Key:         "registry-module-different-name",
 			Source:      "registry.terraform.io/terraform-aws-modules/ec2-instance/aws",
 			Version:     "3.4.0",
 			Dir:         ".infracost/terraform_modules/f8b5f5ddb85ee755b31c8b76d2801f5b",
-			DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-ec2-instance?ref=v3.4.0",
+			DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-ec2-instance?ref=ab731d112e37971368066b5dbecf35b075a853aa",
 		},
 		{
 			Key:    "git-module",
@@ -107,7 +107,7 @@ func TestNestedModules(t *testing.T) {
 			Source:      "registry.terraform.io/terraform-aws-modules/sns/aws",
 			Version:     "3.1.0",
 			Dir:         ".infracost/terraform_modules/b72552bcaa63a49783f9a735a697c662",
-			DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-sns?ref=v3.1.0",
+			DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-sns?ref=c8a2f796a46ba2fe3202b38ecac54f3f3220afac",
 		},
 		{
 			Key:    "local-module.nested-git-module",
@@ -119,7 +119,7 @@ func TestNestedModules(t *testing.T) {
 			Source:      "registry.terraform.io/terraform-aws-modules/ec2-instance/aws",
 			Version:     "3.4.0",
 			Dir:         ".infracost/terraform_modules/f8b5f5ddb85ee755b31c8b76d2801f5b",
-			DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-ec2-instance?ref=v3.4.0",
+			DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-ec2-instance?ref=ab731d112e37971368066b5dbecf35b075a853aa",
 		},
 	}, TestLoaderE2EOpts{Cleanup: true})
 }
@@ -135,14 +135,14 @@ func TestSubmodules(t *testing.T) {
 			Source:      "registry.terraform.io/terraform-aws-modules/route53/aws//modules/zones",
 			Version:     "2.5.0",
 			Dir:         ".infracost/terraform_modules/d1e3bab8b33f57431ace737ccffbf67f/modules/zones",
-			DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-route53?ref=v2.5.0",
+			DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-route53?ref=97dfbae914056b1a06c213be5d5834bc7eea8433",
 		},
 		{
 			Key:         "registry-submodule-records",
 			Source:      "registry.terraform.io/terraform-aws-modules/route53/aws//modules/records",
 			Version:     "2.5.0",
 			Dir:         ".infracost/terraform_modules/d1e3bab8b33f57431ace737ccffbf67f/modules/records",
-			DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-route53?ref=v2.5.0",
+			DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-route53?ref=97dfbae914056b1a06c213be5d5834bc7eea8433",
 		},
 		{
 			Key:    "git-submodule",
@@ -163,14 +163,14 @@ func TestModuleMultipleUses(t *testing.T) {
 			Source:      "registry.terraform.io/terraform-aws-modules/ec2-instance/aws",
 			Version:     "3.4.0",
 			Dir:         ".infracost/terraform_modules/f8b5f5ddb85ee755b31c8b76d2801f5b",
-			DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-ec2-instance?ref=v3.4.0",
+			DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-ec2-instance?ref=ab731d112e37971368066b5dbecf35b075a853aa",
 		},
 		{
 			Key:         "registry-module-2",
 			Source:      "registry.terraform.io/terraform-aws-modules/ec2-instance/aws",
 			Version:     "3.4.0",
 			Dir:         ".infracost/terraform_modules/f8b5f5ddb85ee755b31c8b76d2801f5b",
-			DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-ec2-instance?ref=v3.4.0",
+			DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-ec2-instance?ref=ab731d112e37971368066b5dbecf35b075a853aa",
 		},
 	}, TestLoaderE2EOpts{Cleanup: true})
 }
@@ -186,14 +186,14 @@ func TestModuleMultipleUsesMissingManifest(t *testing.T) {
 			Source:      "registry.terraform.io/terraform-aws-modules/ec2-instance/aws",
 			Version:     "3.4.0",
 			Dir:         ".infracost/terraform_modules/f8b5f5ddb85ee755b31c8b76d2801f5b",
-			DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-ec2-instance?ref=v3.4.0",
+			DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-ec2-instance?ref=ab731d112e37971368066b5dbecf35b075a853aa",
 		},
 		{
 			Key:         "registry-module-2",
 			Source:      "registry.terraform.io/terraform-aws-modules/ec2-instance/aws",
 			Version:     "3.4.0",
 			Dir:         ".infracost/terraform_modules/f8b5f5ddb85ee755b31c8b76d2801f5b",
-			DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-ec2-instance?ref=v3.4.0",
+			DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-ec2-instance?ref=ab731d112e37971368066b5dbecf35b075a853aa",
 		},
 	}
 
@@ -288,14 +288,14 @@ func TestMultiProject(t *testing.T) {
 			Source:      "registry.terraform.io/terraform-aws-modules/ec2-instance/aws",
 			Version:     "3.4.0",
 			Dir:         ".infracost/terraform_modules/f8b5f5ddb85ee755b31c8b76d2801f5b",
-			DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-ec2-instance?ref=v3.4.0",
+			DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-ec2-instance?ref=ab731d112e37971368066b5dbecf35b075a853aa",
 		},
 		{
 			Key:         "registry-module-different-name",
 			Source:      "registry.terraform.io/terraform-aws-modules/ec2-instance/aws",
 			Version:     "3.4.0",
 			Dir:         ".infracost/terraform_modules/f8b5f5ddb85ee755b31c8b76d2801f5b",
-			DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-ec2-instance?ref=v3.4.0",
+			DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-ec2-instance?ref=ab731d112e37971368066b5dbecf35b075a853aa",
 		},
 		{
 			Key:    "git-module",
@@ -312,7 +312,7 @@ func TestMultiProject(t *testing.T) {
 			Source:      "registry.terraform.io/terraform-aws-modules/sns/aws",
 			Version:     "3.1.0",
 			Dir:         ".infracost/terraform_modules/b72552bcaa63a49783f9a735a697c662",
-			DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-sns?ref=v3.1.0",
+			DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-sns?ref=c8a2f796a46ba2fe3202b38ecac54f3f3220afac",
 		},
 		{
 			Key:    "local-module.nested-git-module",
@@ -324,7 +324,7 @@ func TestMultiProject(t *testing.T) {
 			Source:      "registry.terraform.io/terraform-aws-modules/ec2-instance/aws",
 			Version:     "3.4.0",
 			Dir:         ".infracost/terraform_modules/f8b5f5ddb85ee755b31c8b76d2801f5b",
-			DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-ec2-instance?ref=v3.4.0",
+			DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-ec2-instance?ref=ab731d112e37971368066b5dbecf35b075a853aa",
 		},
 	})
 
@@ -334,14 +334,14 @@ func TestMultiProject(t *testing.T) {
 			Source:      "registry.terraform.io/terraform-aws-modules/ec2-instance/aws",
 			Version:     "3.4.0",
 			Dir:         ".infracost/terraform_modules/f8b5f5ddb85ee755b31c8b76d2801f5b",
-			DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-ec2-instance?ref=v3.4.0",
+			DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-ec2-instance?ref=ab731d112e37971368066b5dbecf35b075a853aa",
 		},
 		{
 			Key:         "registry-module-different-name",
 			Source:      "registry.terraform.io/terraform-aws-modules/ec2-instance/aws",
 			Version:     "3.4.0",
 			Dir:         ".infracost/terraform_modules/f8b5f5ddb85ee755b31c8b76d2801f5b",
-			DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-ec2-instance?ref=v3.4.0",
+			DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-ec2-instance?ref=ab731d112e37971368066b5dbecf35b075a853aa",
 		},
 		{
 			Key:    "git-module",
@@ -363,7 +363,7 @@ func TestMultiProject(t *testing.T) {
 			Source:      "registry.terraform.io/terraform-aws-modules/sns/aws",
 			Version:     "3.1.0",
 			Dir:         ".infracost/terraform_modules/b72552bcaa63a49783f9a735a697c662",
-			DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-sns?ref=v3.1.0",
+			DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-sns?ref=c8a2f796a46ba2fe3202b38ecac54f3f3220afac",
 		},
 		{
 			Key:    "local-module.nested-git-module",
@@ -375,7 +375,7 @@ func TestMultiProject(t *testing.T) {
 			Source:      "registry.terraform.io/terraform-aws-modules/ec2-instance/aws",
 			Version:     "3.4.0",
 			Dir:         ".infracost/terraform_modules/f8b5f5ddb85ee755b31c8b76d2801f5b",
-			DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-ec2-instance?ref=v3.4.0",
+			DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-ec2-instance?ref=ab731d112e37971368066b5dbecf35b075a853aa",
 		},
 	})
 
@@ -439,7 +439,7 @@ func TestSourceMapRegistryModule(t *testing.T) {
 					Key:         "registry-module",
 					Source:      "registry.terraform.io/terraform-aws-modules/ec2-instance/aws",
 					Version:     "3.4.0",
-					DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-ec2-instance?ref=v3.4.0",
+					DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-ec2-instance?ref=ab731d112e37971368066b5dbecf35b075a853aa",
 				},
 			},
 		},
@@ -482,7 +482,7 @@ func TestSourceMapRegistryModule(t *testing.T) {
 					Key:         "registry-module",
 					Source:      "registry.terraform.io/terraform-aws-modules/ec2-instance/aws",
 					Version:     "3.4.0",
-					DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-ec2-instance?ref=v3.4.0",
+					DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-ec2-instance?ref=ab731d112e37971368066b5dbecf35b075a853aa",
 				},
 			},
 		},
@@ -496,7 +496,7 @@ func TestSourceMapRegistryModule(t *testing.T) {
 					Key:         "registry-module",
 					Source:      "registry.terraform.io/terraform-aws-modules/ec2-instance/aws",
 					Version:     "3.4.0",
-					DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-ec2-instance?ref=v3.4.0",
+					DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-ec2-instance?ref=ab731d112e37971368066b5dbecf35b075a853aa",
 				},
 			},
 		},
@@ -527,7 +527,7 @@ func TestSourceMapRegistrySubmodule(t *testing.T) {
 					Key:         "registry-submodule",
 					Source:      "registry.terraform.io/terraform-aws-modules/route53/aws//modules/zones",
 					Version:     "2.5.0",
-					DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-route53?ref=v2.5.0",
+					DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-route53?ref=97dfbae914056b1a06c213be5d5834bc7eea8433",
 				},
 			},
 		},
@@ -570,7 +570,7 @@ func TestSourceMapRegistrySubmodule(t *testing.T) {
 					Key:         "registry-submodule",
 					Source:      "registry.terraform.io/terraform-aws-modules/route53/aws//modules/zones",
 					Version:     "2.5.0",
-					DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-route53?ref=v2.5.0",
+					DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-route53?ref=97dfbae914056b1a06c213be5d5834bc7eea8433",
 				},
 			},
 		},
@@ -584,7 +584,7 @@ func TestSourceMapRegistrySubmodule(t *testing.T) {
 					Key:         "registry-submodule",
 					Source:      "registry.terraform.io/terraform-aws-modules/route53/aws//modules/zones",
 					Version:     "2.5.0",
-					DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-route53?ref=v2.5.0",
+					DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-route53?ref=97dfbae914056b1a06c213be5d5834bc7eea8433",
 				},
 			},
 		},
@@ -682,7 +682,7 @@ func TestSourceMapGitModule(t *testing.T) {
 					Key:         "git-module",
 					Source:      "registry.terraform.io/terraform-aws-modules/ec2-instance/aws",
 					Version:     "3.4.0",
-					DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-ec2-instance?ref=v3.4.0",
+					DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-ec2-instance?ref=ab731d112e37971368066b5dbecf35b075a853aa",
 				},
 			},
 		},
@@ -780,7 +780,7 @@ func TestSourceMapGitSubmodule(t *testing.T) {
 					Key:         "git-submodule",
 					Source:      "registry.terraform.io/terraform-aws-modules/route53/aws//modules/zones",
 					Version:     "2.5.0",
-					DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-route53?ref=v2.5.0",
+					DownloadURL: "git::https://github.com/terraform-aws-modules/terraform-aws-route53?ref=97dfbae914056b1a06c213be5d5834bc7eea8433",
 				},
 			},
 		},
