@@ -7,17 +7,15 @@ import (
 
 func getDocDBClusterSnapshotRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
-		Name:  "aws_docdb_cluster_snapshot",
-		RFunc: NewDocDBClusterSnapshot,
+		Name:      "aws_docdb_cluster_snapshot",
+		CoreRFunc: NewDocDBClusterSnapshot,
 	}
 
 }
-func NewDocDBClusterSnapshot(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
+func NewDocDBClusterSnapshot(d *schema.ResourceData) schema.CoreResource {
 	r := &aws.DocDBClusterSnapshot{
 		Address: d.Address,
 		Region:  d.Get("region").String(),
 	}
-
-	r.PopulateUsage(u)
-	return r.BuildResource()
+	return r
 }
