@@ -14,3 +14,12 @@ func TestS3BucketGoldenFile(t *testing.T) {
 
 	tftest.GoldenFileResourceTests(t, "s3_bucket_test")
 }
+
+func TestS3BucketV3GoldenFile(t *testing.T) {
+	t.Parallel()
+	if testing.Short() {
+		t.Skip("skipping test in short mode")
+	}
+
+	tftest.GoldenFileResourceTests(t, "s3_bucket_v3_test")
+}
