@@ -7,12 +7,11 @@ import (
 
 func getActiveDirectoryDomainServiceRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
-		Name:  "azurerm_active_directory_domain_service",
-		RFunc: NewActiveDirectoryDomainService,
+		Name:      "azurerm_active_directory_domain_service",
+		CoreRFunc: NewActiveDirectoryDomainService,
 	}
 }
-func NewActiveDirectoryDomainService(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
+func NewActiveDirectoryDomainService(d *schema.ResourceData) schema.CoreResource {
 	r := &azure.ActiveDirectoryDomainService{Address: d.Address, Region: lookupRegion(d, []string{}), SKU: d.Get("sku").String()}
-	r.PopulateUsage(u)
-	return r.BuildResource()
+	return r
 }
