@@ -7,15 +7,14 @@ import (
 
 func getAPIManagementRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
-		Name:  "azurerm_api_management",
-		RFunc: NewAPIManagement,
+		Name:      "azurerm_api_management",
+		CoreRFunc: NewAPIManagement,
 		ReferenceAttributes: []string{
 			"certificate_id",
 		},
 	}
 }
-func NewAPIManagement(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
+func NewAPIManagement(d *schema.ResourceData) schema.CoreResource {
 	r := &azure.APIManagement{Address: d.Address, SKUName: d.Get("sku_name").String(), Region: lookupRegion(d, []string{})}
-	r.PopulateUsage(u)
-	return r.BuildResource()
+	return r
 }
