@@ -7,15 +7,14 @@ import (
 
 func getDNSCNameRecordRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
-		Name:  "azurerm_dns_cname_record",
-		RFunc: NewDNSCNameRecord,
+		Name:      "azurerm_dns_cname_record",
+		CoreRFunc: NewDNSCNameRecord,
 		ReferenceAttributes: []string{
 			"resource_group_name",
 		},
 	}
 }
-func NewDNSCNameRecord(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
+func NewDNSCNameRecord(d *schema.ResourceData) schema.CoreResource {
 	r := &azure.DNSCNameRecord{Address: d.Address, Region: lookupRegion(d, []string{"resource_group_name"})}
-	r.PopulateUsage(u)
-	return r.BuildResource()
+	return r
 }
