@@ -7,15 +7,14 @@ import (
 
 func getPrivateDNSMXRecordRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
-		Name:  "azurerm_private_dns_mx_record",
-		RFunc: NewPrivateDNSMXRecord,
+		Name:      "azurerm_private_dns_mx_record",
+		CoreRFunc: NewPrivateDNSMXRecord,
 		ReferenceAttributes: []string{
 			"resource_group_name",
 		},
 	}
 }
-func NewPrivateDNSMXRecord(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
+func NewPrivateDNSMXRecord(d *schema.ResourceData) schema.CoreResource {
 	r := &azure.PrivateDNSMXRecord{Address: d.Address, Region: lookupRegion(d, []string{"resource_group_name"})}
-	r.PopulateUsage(u)
-	return r.BuildResource()
+	return r
 }
