@@ -7,16 +7,15 @@ import (
 
 func getLoggingFolderBucketConfigRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
-		Name:  "google_logging_folder_bucket_config",
-		RFunc: NewLoggingFolderBucketConfig,
+		Name:      "google_logging_folder_bucket_config",
+		CoreRFunc: NewLoggingFolderBucketConfig,
 	}
 }
 
-func NewLoggingFolderBucketConfig(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
+func NewLoggingFolderBucketConfig(d *schema.ResourceData) schema.CoreResource {
 	r := &google.Logging{
 		Address: d.Address,
 	}
 
-	r.PopulateUsage(u)
-	return r.BuildResource()
+	return r
 }
