@@ -7,14 +7,15 @@ import (
 
 func getSQLDatabaseInstanceRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
-		Name:  "google_sql_database_instance",
-		RFunc: NewSQLDatabaseInstance,
+		Name:      "google_sql_database_instance",
+		CoreRFunc: NewSQLDatabaseInstance,
 		Notes: []string{
 			"Cloud SQL network, SQL Server license, 1-3 years commitments costs are not yet supported.",
 		},
 	}
 }
-func NewSQLDatabaseInstance(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
+
+func NewSQLDatabaseInstance(d *schema.ResourceData) schema.CoreResource {
 	r := &google.SQLDatabaseInstance{
 		Address:              d.Address,
 		DatabaseVersion:      d.Get("database_version").String(),
@@ -31,6 +32,5 @@ func NewSQLDatabaseInstance(d *schema.ResourceData, u *schema.UsageData) *schema
 	} else {
 		r.UseIPV4 = true // Should use ipv4 if the ipv4_enabled is empty
 	}
-	r.PopulateUsage(u)
-	return r.BuildResource()
+	return r
 }
