@@ -4,10 +4,11 @@ import (
 	"context"
 	"fmt"
 
+	"github.com/shopspring/decimal"
+
 	"github.com/infracost/infracost/internal/resources"
 	"github.com/infracost/infracost/internal/schema"
 	"github.com/infracost/infracost/internal/usage/aws"
-	"github.com/shopspring/decimal"
 )
 
 type DynamoDBTable struct {
@@ -171,6 +172,7 @@ func (a *DynamoDBTable) wcuCostComponent(region string, provisionedWCU *int64, a
 			PurchaseOption:   strPtr("on_demand"),
 			DescriptionRegex: strPtr("/beyond the free tier/"),
 		},
+		UsageBased: autoscaling,
 	}
 }
 
@@ -202,6 +204,7 @@ func (a *DynamoDBTable) rcuCostComponent(region string, provisionedRCU *int64, a
 			PurchaseOption:   strPtr("on_demand"),
 			DescriptionRegex: strPtr("/beyond the free tier/"),
 		},
+		UsageBased: autoscaling,
 	}
 }
 
@@ -303,6 +306,7 @@ func (a *DynamoDBTable) wruCostComponent(region string, monthlyWRU *int64) *sche
 		PriceFilter: &schema.PriceFilter{
 			PurchaseOption: strPtr("on_demand"),
 		},
+		UsageBased: true,
 	}
 }
 
@@ -328,6 +332,7 @@ func (a *DynamoDBTable) rruCostComponent(region string, monthlyRRU *int64) *sche
 		PriceFilter: &schema.PriceFilter{
 			PurchaseOption: strPtr("on_demand"),
 		},
+		UsageBased: true,
 	}
 }
 
@@ -354,6 +359,7 @@ func (a *DynamoDBTable) dataStorageCostComponent(region string, storageGB *int64
 			PurchaseOption:   strPtr("on_demand"),
 			DescriptionRegex: strPtr("/storage used beyond first/"),
 		},
+		UsageBased: true,
 	}
 }
 
@@ -376,6 +382,7 @@ func (a *DynamoDBTable) continuousBackupCostComponent(region string, pitrBackupS
 				{Key: "usagetype", ValueRegex: strPtr("/TimedPITRStorage-ByteHrs/")},
 			},
 		},
+		UsageBased: true,
 	}
 }
 
@@ -395,6 +402,7 @@ func (a *DynamoDBTable) onDemandBackupCostComponent(region string, onDemandBacku
 			Service:       strPtr("AmazonDynamoDB"),
 			ProductFamily: strPtr("Amazon DynamoDB On-Demand Backup Storage"),
 		},
+		UsageBased: true,
 	}
 }
 
@@ -414,6 +422,7 @@ func (a *DynamoDBTable) restoreCostComponent(region string, monthlyDataRestoredG
 			Service:       strPtr("AmazonDynamoDB"),
 			ProductFamily: strPtr("Amazon DynamoDB Restore Data Size"),
 		},
+		UsageBased: true,
 	}
 }
 
@@ -439,5 +448,6 @@ func (a *DynamoDBTable) streamCostComponent(region string, monthlyStreamsRRU *in
 		PriceFilter: &schema.PriceFilter{
 			DescriptionRegex: strPtr("/beyond free tier/"),
 		},
+		UsageBased: true,
 	}
 }
