@@ -11,7 +11,13 @@ type EC2TransitGatewayPeeringAttachment struct {
 	TransitGatewayRegion string
 }
 
-var EC2TransitGatewayPeeringAttachmentUsageSchema = []*schema.UsageItem{}
+func (r *EC2TransitGatewayPeeringAttachment) CoreType() string {
+	return "EC2TransitGatewayPeeringAttachment"
+}
+
+func (r *EC2TransitGatewayPeeringAttachment) UsageSchema() []*schema.UsageItem {
+	return []*schema.UsageItem{}
+}
 
 func (r *EC2TransitGatewayPeeringAttachment) PopulateUsage(u *schema.UsageData) {
 	resources.PopulateArgsWithUsage(r, u)
@@ -27,6 +33,6 @@ func (r *EC2TransitGatewayPeeringAttachment) BuildResource() *schema.Resource {
 		Name: r.Address,
 		CostComponents: []*schema.CostComponent{
 			transitGatewayAttachmentCostComponent(region, "TransitGatewayPeering"),
-		}, UsageSchema: EC2TransitGatewayPeeringAttachmentUsageSchema,
+		}, UsageSchema: r.UsageSchema(),
 	}
 }
