@@ -73,7 +73,7 @@ func createFileWithContents(filePath string) error {
 }`
 	case "terragrunt.hcl.json":
 		content = `include {
-	path = find_in_parent_folders()		
+	path = find_in_parent_folders()
 }`
 	case "Jenkinsfile":
 		content = `
@@ -109,6 +109,12 @@ instance_type = "m5.4xlarge"
 `
 	}
 
+	if strings.HasPrefix(filename, "empty-file") {
+		content = `
+			# This is an empty file
+`
+	}
+
 	return os.WriteFile(filePath, []byte(content), 0600)
 }
 
